@@ -6,18 +6,17 @@
 //
 // SPDX-License-Identifier: GPL-3.0
 
-use std::os::fd::{AsRawFd, RawFd};
+use std::os::fd::RawFd;
 
 use libseccomp::ScmpNotifResp;
 use nix::{errno::Errno, NixPath};
 
 use crate::{
     compat::getdents64,
-    config::{DIRENT_BUF_SIZE, MMAP_MIN_ADDR, PROC_FILE},
-    fs::readlinkat,
+    config::{DIRENT_BUF_SIZE, MMAP_MIN_ADDR},
+    fs::CanonicalPath,
     hook::UNotifyEventRequest,
     kernel::sandbox_path,
-    path::XPathBuf,
     sandbox::Capability,
 };
 
@@ -54,16 +53,13 @@ pub(crate) fn sys_getdents64(request: UNotifyEventRequest) -> ScmpNotifResp {
         // moved to the _open_(2) handler for simplicity and
         // efficiency. The Stat check still takes place.
         let fd = request.get_fd(fd)?;
-        let pfd = XPathBuf::from_self_fd(fd.as_raw_fd());
-
-        let mut dir = match readlinkat(PROC_FILE(), &pfd) {
-            Ok(dir) if dir.is_relative() => {
-                // /proc/1/fd/0 -> pipe:42
-                return Err(Errno::ENOTDIR);
-            }
-            Ok(dir) => dir,
-            Err(_) => return Err(Errno::ENOTDIR),
-        };
+        let mut path = CanonicalPath::new_fd(fd.into(), req.pid())?;
+        if !path.is_dir() {
+            return Err(Errno::ENOTDIR);
+        }
+        #[allow(clippy::disallowed_methods)]
+        let fd = path.dir.take().unwrap();
+        let mut dir = path.take();
 
         // SAFETY: The count argument to the getdents call
         // must not be fully trusted, it can be overly large,
@@ -86,7 +82,8 @@ pub(crate) fn sys_getdents64(request: UNotifyEventRequest) -> ScmpNotifResp {
 
             // Lock sandbox for read to perform Stat access check.
             let sandbox = request.get_sandbox();
-            let safe_name = !sandbox.allow_unsafe_filename();
+            let safe_name = !sandbox.flags.allow_unsafe_filename();
+            let restrict_mkbdev = !sandbox.flags.allow_unsafe_mkbdev();
 
             #[allow(clippy::arithmetic_side_effects)]
             for entry in &mut entries {
@@ -108,6 +105,7 @@ pub(crate) fn sys_getdents64(request: UNotifyEventRequest) -> ScmpNotifResp {
                             Some(&entry.file_type()),
                             Some(entry.as_xpath()),
                             safe_name,
+                            restrict_mkbdev,
                         )
                         .is_err()
                     {
