@@ -63,13 +63,13 @@ syd::main! {
     }
 
     if optj && optJ {
-        eprintln!("-j and -J are mutually exclusive!");
+        eprintln!("syd-cat: -j and -J are mutually exclusive!");
         return Err(Errno::EINVAL.into());
     }
 
     if let Some(name) = name {
         if optj || optJ {
-            eprintln!("-p cannot be used with JSON output!");
+            eprintln!("syd-cat: -p cannot be used with JSON output!");
             return Err(Errno::EINVAL.into());
         }
         if name == "list" {
@@ -238,6 +238,18 @@ fn dump(name: &str) -> SydResult<()> {
                 println!("{command}");
             }
         }
+        "tty_native" => {
+            println!("# Syd profile: TTY-Native");
+            println!(
+                "# Number of rules: {}",
+                syd::config::PROFILE_TTY_NATIVE.len()
+            );
+            println!("# Copyright (c) 2025 Ali Polatel <alip@chesswob.org>");
+            println!("# SPDX-License-Identifier: GPL-3.0");
+            for command in syd::config::PROFILE_TTY_NATIVE {
+                println!("{command}");
+            }
+        }
         "paludis" => {
             println!("# Syd profile: Paludis");
             println!("# Number of rules: {}", syd::config::PROFILE_PALUDIS.len());
