@@ -9,7 +9,6 @@
 // SPDX-License-Identifier: GPL-3.0
 
 use std::{
-    collections::HashSet,
     ffi::OsStr,
     fs::OpenOptions,
     os::unix::{ffi::OsStrExt, fs::OpenOptionsExt},
@@ -22,8 +21,7 @@ use data_encoding::HEXLOWER;
 use libseccomp::ScmpSyscall;
 use nix::{errno::Errno, unistd::isatty};
 use syd::{
-    compat::getdents64, config::DIRENT_BUF_SIZE, err::SydResult, hash::SydRandomState,
-    path::mask_path,
+    compat::getdents64, config::DIRENT_BUF_SIZE, err::SydResult, hash::SydHashSet, path::mask_path,
 };
 
 syd::main! {
@@ -52,7 +50,6 @@ syd::main! {
             println!("- hook");
             println!("- keyring");
             println!("- nice");
-            println!("- noop");
             println!("- page_cache");
             println!("- perf");
             println!("- pkey");
@@ -69,7 +66,7 @@ syd::main! {
             println!("See EXAMPLES section in syd-ls(1) manual page.");
         }
         Some("deny") => {
-            let mut syscall_set: HashSet<_, SydRandomState> = syd::config::SAFE_SYSCALLS
+            let mut syscall_set: SydHashSet<_> = syd::config::SAFE_SYSCALLS
                 .iter()
                 .map(|&s| String::from(s))
                 .collect();
@@ -115,11 +112,6 @@ syd::main! {
                 println!("{name}");
             }
         }
-        Some("noop") => {
-            for name in syd::config::NOOP_SYSCALLS {
-                println!("{name}");
-            }
-        }
         Some("nice") => {
             for name in syd::config::NICE_SYSCALLS {
                 println!("{name}");
@@ -177,7 +169,7 @@ syd::main! {
             }
         }
         Some("personality") => {
-            for (name, _) in syd::config::ALLOWLIST_PERSONALITY {
+            for (name, _) in syd::config::SAFE_PERSONAS {
                 println!("{name}");
             }
         }
